//
// main.ccp
// Created by Adrian Baumgart on 2023-11-10
// License: MIT
//

#include <Arduino.h>
#include <FastLED.h>

void set_all_leds(CRGB leds[], int size, CRGB color);

// Color when interior lights are on (e.g. door is open)
// Color Temperature RGB values from: https://andi-siess.de/rgb-to-color-temperature/
CRGB interior_rgb = CRGB(255, 161, 72);
#define INTERIOR_BRIGHTNESS 200

// Color when ignition is on and when all other lights are off
CRGB driving_rgb = CRGB(240, 17, 17);
#define DRIVING_BRIGHTNESS 50

// Relay config
#define RELAY_1 3

// Input config
#define IGNITION_POWER 7
#define LIGHTING_POWER 8
bool ignition_on = false;
bool lighting_on = false;

// General LED config
#define LED_CHIPSET WS2811
#define LED_COLOR_ORDER BRG

// Front left
#define LED_FL_PIN 5
#define LED_FL_NUM 20
CRGB fl_leds[LED_FL_NUM];

// Front right
#define LED_FR_PIN 6
#define LED_FR_NUM 20
CRGB fr_leds[LED_FR_NUM];


void setup() {
    // Add front-left LEDs
    FastLED.addLeds<LED_CHIPSET, LED_FL_PIN, LED_COLOR_ORDER>(fl_leds, LED_FL_NUM);

    // Add front-right LEDs
    FastLED.addLeds<LED_CHIPSET, LED_FR_PIN, LED_COLOR_ORDER>(fr_leds, LED_FR_NUM);

    pinMode(RELAY_1, OUTPUT);
    pinMode(IGNITION_POWER, INPUT_PULLUP);
    pinMode(LIGHTING_POWER, INPUT_PULLUP);

}

void loop() {
    ignition_on = digitalRead(IGNITION_POWER);
    lighting_on = digitalRead(LIGHTING_POWER);
    if (!ignition_on && !lighting_on) {
        // Turn off LED Strip power
        digitalWrite(RELAY_1, LOW);
    }
    else {
        digitalWrite(RELAY_1, HIGH);
    }

    // Interior light has priority
    if (lighting_on) {
        FastLED.setBrightness(INTERIOR_BRIGHTNESS);
        set_all_leds(fl_leds, LED_FL_NUM, interior_rgb);
        set_all_leds(fr_leds, LED_FR_NUM, interior_rgb);
    }
    else if (ignition_on) {
        FastLED.setBrightness(DRIVING_BRIGHTNESS);
        set_all_leds(fl_leds, LED_FL_NUM, driving_rgb);
        set_all_leds(fr_leds, LED_FR_NUM, driving_rgb);
    }
}

void set_all_leds(CRGB leds[], int size, CRGB color) {
    for(int i = 0;i<size;i++) {
        leds[i] = color;
    }
    FastLED.show();
}